==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolisyon vizit yo<br />@visites@ vizit yo',
	'icone_repartition_actuelle' => 'Afiche repatisyon kounye-a',
	'icone_repartition_visites' => 'Repatisyon vizit yo',
	'icone_statistiques_visites' => 'Estatistik',
	'info_affichier_visites_articles_plus_visites' => 'Fè parè vizit yo <b>tout atik plis vizite depi koumansman :</b>',
	'info_comment_lire_tableau' => 'Kouman fè lekti tablo-a',
	'info_forum_statistiques' => 'Estatistik tout vizit',
	'info_popularite_2' => 'popilarite sit-la :',
	'info_popularite_3' => 'kouman se popilè : @popularite@ ; vizit yo : @visites@',
	'info_popularite_5' => 'Kouman se popilè :',
	'info_visites' => 'vizit yo :',
	'info_visites_plus_populaires' => 'Afiche tout visit pou <b> atik ki pli popilè</b> ak pou <b>denyé atik an liy :</b>',
	'info_zoom' => 'gwoplan',
	'item_gerer_statistiques' => 'Okipe lestatistik yo', # MODIF

	// O
	'onglet_origine_visites' => 'Lorijin vizit yo',
	'onglet_repartition_debut' => 'depi koumansman',
	'onglet_repartition_lang' => 'Repatisyon ant lang',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Plas latik-la, nan klasman popilawite, se enskri sou kote ; populawite atik-la (yon kont nonb vizit pa jou atik-la ki rannkout si li kembe ritm-la kounyen-a) ak nonb vizit ki vini depi koumansman, zot ka afich nan yon bil ki parèt kank w vole sou titr-la.',
	'texte_signification' => 'Tou liy nwa se limaj tout rantré kimilé  (yon total pou tout souribrik), tout liy klèr se nonb visit sa-yo pou chak ribrik.',
	'titre_evolution_visite' => 'Evolisyon vizit yo',
	'titre_liens_entrants' => 'Lyen sa-yo ka rive',
	'titre_page_statistiques' => 'Estatsitik pou tout pati yo nan sit sa a',
	'titre_page_statistiques_visites' => 'Estatistik pou tout vizit yo'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolisyon vizit yo<br />@visites@ vizit yo',
	'icone_repartition_actuelle' => 'Afiche repatisyon kounye-a',
	'icone_repartition_visites' => 'Repatisyon vizit yo',
	'icone_statistiques_visites' => 'Estatistik',
	'info_affichier_visites_articles_plus_visites' => 'Fè parè vizit yo <b>tout atik plis vizite depi koumansman :</b>',
	'info_comment_lire_tableau' => 'Kouman fè lekti tablo-a',
	'info_forum_statistiques' => 'Estatistik tout vizit',
	'info_popularite_2' => 'popilarite sit-la :',
	'info_popularite_3' => 'kouman se popilè : @popularite@ ; vizit yo : @visites@',
	'info_popularite_5' => 'Kouman se popilè :',
	'info_visites' => 'vizit yo :',
	'info_visites_plus_populaires' => 'Afiche tout visit pou <b> atik ki pli popilè</b> ak pou <b>denyé atik an liy :</b>',
	'info_zoom' => 'gwoplan',
	'item_gerer_statistiques' => 'Okipe lestatistik yo', # MODIF

	// O
	'onglet_origine_visites' => 'Lorijin vizit yo',
	'onglet_repartition_debut' => 'depi koumansman',
	'onglet_repartition_lang' => 'Repatisyon ant lang',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Plas latik-la, nan klasman popilawite, se enskri sou kote ; populawite atik-la (yon kont nonb vizit pa jou atik-la ki rannkout si li kembe ritm-la kounyen-a) ak nonb vizit ki vini depi koumansman, zot ka afich nan yon bil ki parèt kank w vole sou titr-la.',
	'texte_signification' => 'Tou liy nwa se limaj tout rantré kimilé  (yon total pou tout souribrik), tout liy klèr se nonb visit sa-yo pou chak ribrik.',
	'titre_evolution_visite' => 'Evolisyon vizit yo',
	'titre_liens_entrants' => 'Lyen sa-yo ka rive',
	'titre_page_statistiques' => 'Estatsitik pou tout pati yo nan sit sa a',
	'titre_page_statistiques_visites' => 'Estatistik pou tout vizit yo',
];
